@@ -7,7 +7,7 @@ import sys
 from enum import Enum
 from functools import partial, reduce
 from itertools import chain
-from types import MappingProxyType
+from types import MappingProxyType, ModuleType
 from typing import (
     TYPE_CHECKING,
     Callable,
@@ -22,35 +22,31 @@ from typing import (
     cast,
 )
 
-from fastjsonschema.draft07 import CodeGeneratorDraft07
-from fastjsonschema.ref_resolver import RefResolver
+import fastjsonschema as FJS
 
 from . import errors, formats
+from .error_reporting import detailed_errors
 from .extra_validations import EXTRA_VALIDATIONS
 from .types import FormatValidationFn, Schema, ValidationFn
 
+_logger = logging.getLogger(__name__)
+_chain_iter = chain.from_iterable
+
 if TYPE_CHECKING:  # pragma: no cover
     from .plugins import PluginWrapper  # noqa
 
-if sys.version_info[:2] >= (3, 7):  # pragma: no cover
-    # TODO: Import directly (no need for conditional) when `python_requires = >= 3.7`
+
+try:  # pragma: no cover
+    if sys.version_info[:2] < (3, 7) or TYPE_CHECKING:  # See #22
+        from importlib_resources import files
+    else:
+        from importlib.resources import files
+
+    def read_text(package: Union[str, ModuleType], resource) -> str:
+        return files(package).joinpath(resource).read_text(encoding="utf-8")
+
+except ImportError:  # pragma: no cover
     from importlib.resources import read_text
-else:  # pragma: no cover
-    try:
-        from pkgutil import get_data  # pragma: no cover
-    except ImportError as ex:
-        msg = "Please install `setuptools` or `importlib_metadata`"
-        raise ImportError(msg) from ex
-
-    # The following "polyfill" is taken from PyScaffold (licensed under MIT)
-    # https://github.com/pyscaffold/pyscaffold/blob/master/LICENSE.txt
-    # https://github.com/pyscaffold/pyscaffold/blob/609f548574618834e6056997aff411b43a24e3fb/src/pyscaffold/templates/__init__.py#L27
-
-    def read_text(package, resource, encoding="utf-8") -> str:  # pragma: no cover
-        data = get_data(package, resource)
-        if data is None:
-            raise FileNotFoundError(f"{resource!r} resource not found in {package!r}")
-        return data.decode(encoding)
 
 
 T = TypeVar("T", bound=Mapping)
@@ -58,18 +54,18 @@ AllPlugins = Enum("AllPlugins", "ALL_PLUGINS")
 ALL_PLUGINS = AllPlugins.ALL_PLUGINS
 
 TOP_LEVEL_SCHEMA = "pyproject_toml"
-PROJECT_TABLE_SCHEMA = "pep621_project"
+PROJECT_TABLE_SCHEMA = "project_metadata"
 
-FORMAT_FUNCTIONS: Mapping[str, FormatValidationFn] = MappingProxyType(
-    {
+
+def _get_public_functions(module: ModuleType) -> Mapping[str, FormatValidationFn]:
+    return {
         fn.__name__.replace("_", "-"): fn
-        for fn in formats.__dict__.values()
+        for fn in module.__dict__.values()
         if callable(fn) and not fn.__name__.startswith("_")
     }
-)
 
-_logger = logging.getLogger(__name__)
-_chain_iter = chain.from_iterable
+
+FORMAT_FUNCTIONS = MappingProxyType(_get_public_functions(formats))
 
 
 def load(name: str, package: str = __package__, ext: str = ".schema.json") -> Schema:
@@ -108,7 +104,8 @@ class SchemaRegistry(Mapping[str, Schema]):
         self._ensure_compatibility(PROJECT_TABLE_SCHEMA, project_table_schema)
         sid = project_table_schema["$id"]
         top_level["project"] = {"$ref": sid}
-        self._schemas = {sid: ("project", f"{__name__} - PEP621", project_table_schema)}
+        origin = f"{__name__} - project metadata"
+        self._schemas = {sid: ("project", origin, project_table_schema)}
 
         # Add tools using Plugins
 
@@ -124,7 +121,8 @@ class SchemaRegistry(Mapping[str, Schema]):
 
         self._main_id = sid = top_level["$id"]
         main_schema = Schema(top_level)
-        self._schemas[sid] = ("<$ROOT>", f"{__name__} - PEP517/518", main_schema)
+        origin = f"{__name__} - build metadata"
+        self._schemas[sid] = ("<$ROOT>", origin, main_schema)
 
     @property
     def spec_version(self) -> str:
@@ -143,7 +141,8 @@ class SchemaRegistry(Mapping[str, Schema]):
         if sid in self._schemas:
             raise errors.SchemaWithDuplicatedId(sid)
         version = schema.get("$schema")
-        if version and version != self.spec_version:
+        # Support schemas with missing trailing # (incorrect, but required before 0.15)
+        if version and version.rstrip("#") != self.spec_version.rstrip("#"):
             raise errors.InvalidSchemaVersion(reference, version, self.spec_version)
         return schema
 
@@ -193,6 +192,7 @@ class Validator:
         format_validators: Mapping[str, FormatValidationFn] = FORMAT_FUNCTIONS,
         extra_validations: Sequence[ValidationFn] = EXTRA_VALIDATIONS,
     ):
+        self._code_cache: Optional[str] = None
         self._cache: Optional[ValidationFn] = None
         self._schema: Optional[Schema] = None
 
@@ -210,10 +210,6 @@ class Validator:
         self._schema_registry = SchemaRegistry(self._plugins)
         self.handlers = RefHandler(self._schema_registry)
 
-        # Only needed while issue #129 of fastjsonschema is not solved
-        self._gen: Optional[CodeGeneratorDraft07] = None
-        self._resolver: Optional[RefResolver] = None
-
     @property
     def registry(self) -> SchemaRegistry:
         return self._schema_registry
@@ -234,13 +230,12 @@ class Validator:
         return self._format_validators
 
     @property
-    def _generator(self):
-        # Only needed while issue #129 of fastjsonschema is not solved
-        if self._gen is None:
-            self._resolver = RefResolver("", self.schema, {}, handlers=self.handlers)
-            formats = dict(self.formats)
-            self._gen = CodeGeneratorDraft07(self.schema, self._resolver, formats)
-        return self._gen
+    def generated_code(self) -> str:
+        if self._code_cache is None:
+            fmts = dict(self.formats)
+            self._code_cache = FJS.compile_to_code(self.schema, self.handlers, fmts)
+
+        return self._code_cache
 
     def __getitem__(self, schema_id: str) -> Schema:
         """Retrieve a schema from registry"""
@@ -248,19 +243,10 @@ class Validator:
 
     def __call__(self, pyproject: T) -> T:
         if self._cache is None:
-            # Only needed while issue #129 of fastjsonschema is not solved
-            generator = self._generator
-            state = generator.global_state
-            exec(generator.func_code, state)
-            resolver = cast(RefResolver, self._resolver)
-            fn = partial(
-                state[resolver.get_scope_name()], custom_formats=self._format_validators
-            )
+            compiled = FJS.compile(self.schema, self.handlers, dict(self.formats))
+            fn = partial(compiled, custom_formats=self._format_validators)
             self._cache = cast(ValidationFn, fn)
-            # Once the issue is solved we can use the `fastjsonschema.compile`
-            # >>> compiled = FJS.compile(self.schema, self.handlers, dict(self.formats))
-            # >>> fn = partial(compiled, custom_formats=self._format_validators)
-            # >>> self._cache = cast(ValidationFn, fn)
 
-        self._cache(pyproject)
-        return reduce(lambda acc, fn: fn(acc), self.extra_validations, pyproject)
+        with detailed_errors():
+            self._cache(pyproject)
+            return reduce(lambda acc, fn: fn(acc), self.extra_validations, pyproject)
