@@ -10,9 +10,20 @@ import sys
 from contextlib import contextmanager
 from itertools import chain
 from textwrap import dedent, wrap
-from typing import Callable, Dict, List, NamedTuple, Sequence, Type, TypeVar
+from typing import (
+    Callable,
+    Dict,
+    Iterator,
+    List,
+    NamedTuple,
+    Sequence,
+    Tuple,
+    Type,
+    TypeVar,
+)
 
 from . import __version__
+from . import _tomllib as tomllib
 from .api import Validator
 from .errors import ValidationError
 from .plugins import PluginWrapper
@@ -21,14 +32,7 @@ from .plugins import list_from_entry_points as list_plugins_from_entry_points
 _logger = logging.getLogger(__package__)
 T = TypeVar("T", bound=NamedTuple)
 
-
-try:
-    from tomli import loads
-except ImportError:  # pragma: no cover
-    try:
-        from toml import loads  # type: ignore
-    except ImportError as ex:
-        raise ImportError("Please install a TOML parser (e.g. `tomli`)") from ex
+_REGULAR_EXCEPTIONS = (ValidationError, tomllib.TOMLDecodeError)
 
 
 @contextmanager
@@ -42,6 +46,8 @@ def critical_logging():
         raise
 
 
+_STDIN = argparse.FileType("r")("-")
+
 META: Dict[str, dict] = {
     "version": dict(
         flags=("-V", "--version"),
@@ -50,8 +56,8 @@ META: Dict[str, dict] = {
     ),
     "input_file": dict(
         dest="input_file",
-        nargs="?",
-        default="-",
+        nargs="*",
+        # default=[_STDIN],  # postponed to facilitate testing
         type=argparse.FileType("r"),
         help="TOML file to be verified (`stdin` by default)",
     ),
@@ -94,7 +100,7 @@ META: Dict[str, dict] = {
 
 
 class CliParams(NamedTuple):
-    input_file: io.TextIOBase
+    input_file: List[io.TextIOBase]
     plugins: List[PluginWrapper]
     loglevel: int = logging.WARNING
     dump_json: bool = False
@@ -104,6 +110,7 @@ def __meta__(plugins: Sequence[PluginWrapper]) -> Dict[str, dict]:
     """'Hyper parameters' to instruct :mod:`argparse` how to create the CLI"""
     meta = {k: v.copy() for k, v in META.items()}
     meta["enable"]["choices"] = set([p.tool for p in plugins])
+    meta["input_file"]["default"] = [_STDIN]  # lazily defined to facilitate testing
     return meta
 
 
@@ -137,7 +144,7 @@ def parse_args(
     enabled = params.pop("enable", ())
     disabled = params.pop("disable", ())
     params["plugins"] = select_plugins(plugins, enabled, disabled)
-    return params_class(**params)
+    return params_class(**params)  # type: ignore[call-overload]
 
 
 def select_plugins(
@@ -164,13 +171,18 @@ def setup_logging(loglevel: int):
 
 
 @contextmanager
-def exceptisons2exit():
+def exceptions2exit():
     try:
         yield
-    except ValidationError as ex:
+    except _ExceptionGroup as group:
+        for prefix, ex in group:
+            print(prefix)
+            _logger.error(str(ex) + "\n")
+        raise SystemExit(1)
+    except _REGULAR_EXCEPTIONS as ex:
         _logger.error(str(ex))
         raise SystemExit(1)
-    except Exception as ex:
+    except Exception as ex:  # pragma: no cover
         _logger.error(f"{ex.__class__.__name__}: {ex}\n")
         _logger.debug("Please check the following information:", exc_info=True)
         raise SystemExit(1)
@@ -191,16 +203,32 @@ def run(args: Sequence[str] = ()):
     params: CliParams = parse_args(args, plugins)
     setup_logging(params.loglevel)
     validator = Validator(plugins=params.plugins)
-    toml_equivalent = loads(params.input_file.read())
+
+    exceptions = _ExceptionGroup()
+    for file in params.input_file:
+        try:
+            _run_on_file(validator, params, file)
+        except _REGULAR_EXCEPTIONS as ex:
+            exceptions.add(f"Invalid {_format_file(file)}", ex)
+
+    exceptions.raise_if_any()
+
+    return 0
+
+
+def _run_on_file(validator: Validator, params: CliParams, file: io.TextIOBase):
+    if file in (sys.stdin, _STDIN):
+        print("Expecting input via `stdin`...", file=sys.stderr, flush=True)
+
+    toml_equivalent = tomllib.loads(file.read())
     validator(toml_equivalent)
     if params.dump_json:
         print(json.dumps(toml_equivalent, indent=2))
     else:
-        print("Valid file")
-    return 0
+        print(f"Valid {_format_file(file)}")
 
 
-main = exceptisons2exit()(run)
+main = exceptions2exit()(run)
 
 
 class Formatter(argparse.RawTextHelpFormatter):
@@ -225,4 +253,32 @@ def _flatten_str(text: str) -> str:
 def _format_plugin_help(plugin: PluginWrapper) -> str:
     help_text = plugin.help_text
     help_text = f": {_flatten_str(help_text)}" if help_text else ""
-    return f'* "{plugin.tool}"{help_text}'
+    return f"* {plugin.tool!r}{help_text}"
+
+
+def _format_file(file: io.TextIOBase) -> str:
+    if hasattr(file, "name") and file.name:
+        return f"file: {file.name}"
+    return "file"  # pragma: no cover
+
+
+class _ExceptionGroup(Exception):
+    _members: List[Tuple[str, Exception]]
+
+    def __init__(self):
+        self._members = []
+        super().__init__()
+
+    def add(self, prefix: str, ex: Exception):
+        self._members.append((prefix, ex))
+
+    def __iter__(self) -> Iterator[Tuple[str, Exception]]:
+        return iter(self._members)
+
+    def raise_if_any(self):
+        number = len(self._members)
+        if number == 1:
+            print(self._members[0][0])
+            raise self._members[0][1]
+        if number > 0:
+            raise self
