@@ -7,7 +7,7 @@ from contextlib import contextmanager
 from textwrap import indent, wrap
 from typing import Any, Dict, Iterator, List, Optional, Sequence, Union, cast
 
-from ._vendor.fastjsonschema import JsonSchemaValueException
+from fastjsonschema import JsonSchemaValueException
 
 _logger = logging.getLogger(__name__)
 
@@ -24,7 +24,7 @@ _SKIP_DETAILS = (
     "must not be there",
 )
 
-_NEED_DETAILS = {"anyOf", "oneOf", "anyOf", "contains", "propertyNames", "not", "items"}
+_NEED_DETAILS = {"anyOf", "oneOf", "allOf", "contains", "propertyNames", "not", "items"}
 
 _CAMEL_CASE_SPLITTER = re.compile(r"\W+|([A-Z][^A-Z\W]*)")
 _IDENTIFIER = re.compile(r"^[\w_]+$", re.I)
@@ -129,8 +129,9 @@ class _ErrorFormatting:
 
     def _expand_details(self) -> str:
         optional = []
-        desc_lines = self.ex.definition.pop("$$description", [])
-        desc = self.ex.definition.pop("description", None) or " ".join(desc_lines)
+        definition = self.ex.definition or {}
+        desc_lines = definition.pop("$$description", [])
+        desc = definition.pop("description", None) or " ".join(desc_lines)
         if desc:
             description = "\n".join(
                 wrap(
@@ -142,7 +143,7 @@ class _ErrorFormatting:
                 )
             )
             optional.append(f"DESCRIPTION:\n{description}")
-        schema = json.dumps(self.ex.definition, indent=4)
+        schema = json.dumps(definition, indent=4)
         value = json.dumps(self.ex.value, indent=4)
         defaults = [
             f"GIVEN VALUE:\n{indent(value, '    ')}",
@@ -313,6 +314,6 @@ class _SummaryWriter:
 def _separate_terms(word: str) -> List[str]:
     """
     >>> _separate_terms("FooBar-foo")
-    "foo bar foo"
+    ['foo', 'bar', 'foo']
     """
     return [w.lower() for w in _CAMEL_CASE_SPLITTER.split(word) if w]
