@@ -8,7 +8,7 @@
 import sys
 from string import Template
 from textwrap import dedent
-from typing import Callable, Iterable, List, Optional
+from typing import Any, Callable, Iterable, List, Optional, cast
 
 from .. import __version__
 from ..types import Plugin
@@ -47,6 +47,9 @@ class PluginWrapper:
             return ""
         return Template(tpl).safe_substitute(tool=self.tool, id=self.id)
 
+    def __repr__(self) -> str:
+        return f"{self.__class__.__name__}({self.tool!r}, {self.id})"
+
 
 def iterate_entry_points(group=ENTRYPOINT_GROUP) -> Iterable[EntryPoint]:
     """Produces a generator yielding an EntryPoint object for each plugin registered
@@ -59,7 +62,8 @@ def iterate_entry_points(group=ENTRYPOINT_GROUP) -> Iterable[EntryPoint]:
     if hasattr(entries, "select"):  # pragma: no cover
         # The select method was introduced in importlib_metadata 3.9 (and Python 3.10)
         # and the previous dict interface was declared deprecated
-        entries_ = entries.select(group=group)  # type: ignore
+        select = cast(Any, getattr(entries, "select"))  # typecheck gymnastics # noqa
+        entries_: Iterable[EntryPoint] = select(group=group)
     else:  # pragma: no cover
         # TODO: Once Python 3.10 becomes the oldest version supported, this fallback and
         #       conditional statement can be removed.
@@ -97,15 +101,16 @@ def list_from_entry_points(
 
 
 class ErrorLoadingPlugin(RuntimeError):
-    """There was an error loading '{plugin}'.
+    _DESC = """There was an error loading '{plugin}'.
     Please make sure you have installed a version of the plugin that is compatible
     with {package} {version}. You can also try uninstalling it.
     """
+    __doc__ = _DESC
 
     def __init__(self, plugin: str = "", entry_point: Optional[EntryPoint] = None):
         if entry_point and not plugin:
             plugin = getattr(entry_point, "module", entry_point.name)
 
         sub = dict(package=__package__, version=__version__, plugin=plugin)
-        msg = dedent(self.__doc__ or "").format(**sub).splitlines()
+        msg = dedent(self._DESC).format(**sub).splitlines()
         super().__init__(f"{msg[0]}\n{' '.join(msg[1:])}")
